<?php
/**
 * @package Cache
 * @subpackage MachII_cache_PearCacheLite5
 * @author Alan Richmond <alan@aardwolfweb.com>
 */
 
// +----------------------------------------------------------------------+
// | Mach-II :: MachII_cache_PearCacheLite5                               |
// +----------------------------------------------------------------------+
// | Copyright (c) 2004 Alan Richmond                                     |
// | All rights reserved.                                                 |
// +----------------------------------------------------------------------+
// | Redistribution and use in source and binary forms, with or without   |
// | modification, are permitted provided that the following conditions   |
// | are met:                                                             |
// |                                                                      |
// | Redistributions of source code must retain the above copyright       |
// | notice, this list of conditions and the following disclaimer.        |
// |                                                                      |
// | Redistributions in binary form must reproduce the above copyright    |
// | notice, this list of conditions and the following disclaimer in the  |
// | documentation and/or other materials provided with the distribution. |
// |                                                                      |
// | Neither the name of Alan Richmond nor the names of his contributors  |
// | may be used to endorse or promote products derived from this         |
// | software without specific prior written permission.                  |
// |                                                                      |
// | THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS  |
// | "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT    |
// | LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS    |
// | FOR A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE      |
// | REGENTS OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,          |
// | INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, |
// | BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS|
// | OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED   |
// | AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT          |
// | LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY|
// | WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE          |
// | POSSIBILITY OF SUCH DAMAGE.                                          |
// +----------------------------------------------------------------------+

/**
 * File containing the Cache_Lite class.
 */
require_once 'Cache/Lite.php';

/**
 * Mach-II cache facade for the file-based PEAR Cache_Lite.
 * 
 * Mach-II cache facade for PEAR {@link http://pear.php.net/Cache_Lite Cache_Lite},
 * a light-weight file-based cache system.  Cache_Light must be
 * correctly installed before this facade may be used.
 * @package Cache
 * @subpackage MachII_cache_PearCacheLite5
 * @author Alan Richmond <alan@aardwolfweb.com>
 */
class MachII_cache_PearCacheLite extends MachII_framework_Cache
{
    /**
     * Constructor
     * 
     * Set some defaults and get the cache ready for use.
     * 
     * Any valid Cache_Lite option may be passed in through the
     * 'options' array.  See the Cache_Lite source for more details.
     * The following defaults are set:
     * <ul>
     *    <li>automaticSerialization = true - This should not be changed!</li>
     *    <li>cacheDir = session.save_path - The directory session data is
     *        stored in.  Be careful with sensitive data on shared hosts!
     *        Change it if needed.</li>
     *    <li>lifeTime = 2592000 (30 days).</li>
     * </ul>
     * @uses MachII_util_Cache::__construct
     * @param string a name unique to this application
     * @param array an associative array of Cache_Lite options
     */
    public function __construct($appName, $options = array())
    {
        // Always serialize values
        $options['automaticSerialization'] = true;
        
        // Save cache files in the same directory as session files
        if (!isset($options['cacheDir'])) {
            $savePath = ini_get('session.save_path');
            $lastChar = substr($savePath, -1, 1);
            if (($lastChar != '/')
            && ($lastChar != '\\')) {
                $savePath .= DIRECTORY_SEPARATOR;
            }
            $options['cacheDir'] = $savePath;
        }
        // 
        if (!isset($options['lifeTime'])) {
            $options['lifeTime'] = 2592000; // 30 days
        }
        
        parent::__construct($appName, $options);
    }
    
    /**
     * @param string
     * @param mixed
     * @param array
     * @uses Cache_Lite::save()
     * @return boolean
     */
    public function save($name, $value)
    {
        $result = $this->cache->save($value, $name, $this->appName);       
        
        return $result;
    }
    
    /**
     * @param string
     * @uses Cache_Light::get()
     * @return mixed
     */
    public function get($varName)
    {
        $value = $this->cache->get($varName, $this->appName);
        
        return $value;
    }
    
    /**
     * @uses Cache_Light::clean()
     */
    public function clear()
    {
        $this->cache->clean($this->appName);
    }
    
    /**
     * Instantiate a new Cache_Lite object.
     * @uses Cache_Light
     * @return Cache_Lite
     */
    public function createCache()
    {
        $cache = new Cache_Lite($this->options);
        
        return $cache;
    }

}

?>